@@ -2,7 +2,8 @@
 import  sys
 import os
 from os import path
-sys.path.append((os.path.dirname(path.dirname(__file__))))
+sys.path.append('./')
+sys.path.append('../')
 from ctypes import *
 import sys
 import  time
