@@ -3,11 +3,12 @@ import copy
 import sys
 import  os
 from os import path
+sys.path.append('.')
 sys.path.append('./')
 sys.path.append('../')
 from commFunction import getip,log_time,global_result,sftp_connect,sftp_put,sftp_disconnect,get_file_path
 import shutil
-from  socketClient import SocketClient
+from  POLQA.socketClient import SocketClient
 import datetime
 
 
